import { ReactNode } from 'react';

import { MenuInitialState, useMenuState } from 'reakit/Menu';

import { SelectButton } from './button';
import { SelectContext } from './context';
import { SelectOption } from './option';
import { SelectList } from './list';

interface SelectProps {
  name: string;
  children?: ReactNode;
  className?: string;
  placeholder?: string;
  defaultValue?: string;
  options?: MenuInitialState;
}

export function Select({
  name,
  children,
  className,
  placeholder,
  defaultValue,
  options = {},
}: SelectProps) {
  const state = useMenuState({
    animated: true,
    placement: 'bottom-end',
    gutter: 8,
    ...options,
  });

  console.log(defaultValue);

  return (
    <div className={className}>
      <SelectContext.Provider value={{ name, state }}>
        <SelectButton>{placeholder}</SelectButton>
        <SelectList>{children}</SelectList>
      </SelectContext.Provider>
    </div>
  );
}

Select.defaultProps = {
  children: null,
  className: '',
  placeholder: '',
  defaultValue: undefined,
  options: {},
};

Select.Option = SelectOption;
